==> pyls-spyder-0.2.0.tar.gz: pyls-spyder-0.2.0/CHANGELOG.md <==
## Version 0.2.0 (2020/11/23)

### Issues Closed

* [Issue 12](https://github.com/spyder-ide/pyls-spyder/issues/12) - Release v0.2.0
* [Issue 9](https://github.com/spyder-ide/pyls-spyder/issues/9) - Some cell patterns are not detected in the Outline explorer ([PR 10](https://github.com/spyder-ide/pyls-spyder/pull/10) by [@andfoy](https://github.com/andfoy))
* [Issue 8](https://github.com/spyder-ide/pyls-spyder/issues/8) - Some issues with special comments in the outline explorer ([PR 10](https://github.com/spyder-ide/pyls-spyder/pull/10) by [@andfoy](https://github.com/andfoy))

In this release 3 issues were closed.

### Pull Requests Merged

* [PR 11](https://github.com/spyder-ide/pyls-spyder/pull/11) - Remove dependency on separate mock package, by [@bnavigator](https://github.com/bnavigator)
* [PR 10](https://github.com/spyder-ide/pyls-spyder/pull/10) - PR: Add additional cases for code cells and block comments, by [@andfoy](https://github.com/andfoy) ([9](https://github.com/spyder-ide/pyls-spyder/issues/9), [8](https://github.com/spyder-ide/pyls-spyder/issues/8))

In this release 2 pull requests were closed.


## Version 0.1.1 (2020/10/28)

### Issues Closed

* [Issue 7](https://github.com/spyder-ide/pyls-spyder/issues/7) - Release v0.1.1

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 6](https://github.com/spyder-ide/pyls-spyder/pull/6) - PR: Add options to group cells and disable/enable block comments, by [@andfoy](https://github.com/andfoy)

In this release 1 pull request was closed.


## Version 0.1.0 (2020/09/29)

### Issues Closed

* [Issue 4](https://github.com/spyder-ide/pyls-spyder/issues/4) - Add RELEASE instructions ([PR 5](https://github.com/spyder-ide/pyls-spyder/pull/5) by [@andfoy](https://github.com/andfoy))
* [Issue 3](https://github.com/spyder-ide/pyls-spyder/issues/3) - Release v0.1.0

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 5](https://github.com/spyder-ide/pyls-spyder/pull/5) - PR: Add RELEASE instructions and update source distribution contents, by [@andfoy](https://github.com/andfoy) ([4](https://github.com/spyder-ide/pyls-spyder/issues/4))
* [PR 2](https://github.com/spyder-ide/pyls-spyder/pull/2) - PR: Parse cells and block comments and include them as part of textDocument/symbol call, by [@andfoy](https://github.com/andfoy)

In this release 2 pull requests were closed.

==> pyls-spyder_0.3.0.orig.tar.gz: pyls-spyder-0.3.0/CHANGELOG.md <==
## Version 0.3.0 (2020/12/11)

### Issues Closed

* [Issue 16](https://github.com/spyder-ide/pyls-spyder/issues/16) - Release v0.3.0

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 15](https://github.com/spyder-ide/pyls-spyder/pull/15) - PR: Add support for textDocument/foldingRange call for code cells, by [@andfoy](https://github.com/andfoy) ([7846](https://github.com/spyder-ide/spyder/issues/7846))

In this release 1 pull request was closed.


## Version 0.2.1 (2020/11/24)

### Issues Closed

* [Issue 14](https://github.com/spyder-ide/pyls-spyder/issues/14) - Release v0.2.1

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 13](https://github.com/spyder-ide/pyls-spyder/pull/13) - PR: Pin minimum Python version to 3.6, by [@andfoy](https://github.com/andfoy)

In this release 1 pull request was closed.

###############################################################################


## Version 0.2.0 (2020/11/23)

### Issues Closed

* [Issue 12](https://github.com/spyder-ide/pyls-spyder/issues/12) - Release v0.2.0
* [Issue 9](https://github.com/spyder-ide/pyls-spyder/issues/9) - Some cell patterns are not detected in the Outline explorer ([PR 10](https://github.com/spyder-ide/pyls-spyder/pull/10) by [@andfoy](https://github.com/andfoy))
* [Issue 8](https://github.com/spyder-ide/pyls-spyder/issues/8) - Some issues with special comments in the outline explorer ([PR 10](https://github.com/spyder-ide/pyls-spyder/pull/10) by [@andfoy](https://github.com/andfoy))

In this release 3 issues were closed.

### Pull Requests Merged

* [PR 11](https://github.com/spyder-ide/pyls-spyder/pull/11) - Remove dependency on separate mock package, by [@bnavigator](https://github.com/bnavigator)
* [PR 10](https://github.com/spyder-ide/pyls-spyder/pull/10) - PR: Add additional cases for code cells and block comments, by [@andfoy](https://github.com/andfoy) ([9](https://github.com/spyder-ide/pyls-spyder/issues/9), [8](https://github.com/spyder-ide/pyls-spyder/issues/8))

In this release 2 pull requests were closed.


## Version 0.1.1 (2020/10/28)

### Issues Closed

* [Issue 7](https://github.com/spyder-ide/pyls-spyder/issues/7) - Release v0.1.1

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 6](https://github.com/spyder-ide/pyls-spyder/pull/6) - PR: Add options to group cells and disable/enable block comments, by [@andfoy](https://github.com/andfoy)

In this release 1 pull request was closed.


## Version 0.1.0 (2020/09/29)

### Issues Closed

* [Issue 4](https://github.com/spyder-ide/pyls-spyder/issues/4) - Add RELEASE instructions ([PR 5](https://github.com/spyder-ide/pyls-spyder/pull/5) by [@andfoy](https://github.com/andfoy))
* [Issue 3](https://github.com/spyder-ide/pyls-spyder/issues/3) - Release v0.1.0

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 5](https://github.com/spyder-ide/pyls-spyder/pull/5) - PR: Add RELEASE instructions and update source distribution contents, by [@andfoy](https://github.com/andfoy) ([4](https://github.com/spyder-ide/pyls-spyder/issues/4))
* [PR 2](https://github.com/spyder-ide/pyls-spyder/pull/2) - PR: Parse cells and block comments and include them as part of textDocument/symbol call, by [@andfoy](https://github.com/andfoy)

In this release 2 pull requests were closed.
